==> drd-8.x-3.4.tar.gz: drd/src/Plugin/Action/BaseEntity.php <==
<?php

namespace Drupal\drd\Plugin\Action;

use Drupal\Core\Access\AccessResultAllowed;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\drd\Entity\BaseInterface;

/**
 * Base class for DRD Action plugins.
 */
abstract class BaseEntity extends Base implements BaseEntityInterface {

  /** @var BaseInterface $drdEntity */
  protected $drdEntity;

  /**
   * {@inheritdoc}
   */
  public function access($domain, AccountInterface $account = NULL, $return_as_object = FALSE) {
    $this->drdEntity = $domain;
    return $return_as_object ? new AccessResultAllowed() : TRUE;

    /**
     * TODO: during cron the current user is anonymous and that would let all
     * actions fail. Let's find out if there is a better way maybe using context
     * to find out if we are called during cron or otherwise.
    $access = $domain->status->access('edit', $account, TRUE)
    ->andIf($domain->access('update', $account, TRUE));

    return $return_as_object ? $access : $access->isAllowed();
     */
  }

  /**
   * @param EntityInterface $entity
   * @param string $severity
   * @param string $message
   * @param array $arguments
   */
  protected function log($entity, $severity, $message, $arguments = []) {
    if (!method_exists(\Drupal::logger('drd'), $severity)) {
      $severity = 'emergency';
    }
    $arguments['@plugin_id'] = $this->pluginId;
    $arguments['@entity_id'] = $entity->id();
    $arguments['@entity_name'] = $entity->label();
    $arguments['@entity_type'] = $entity->getEntityTypeId();
    $arguments['link'] = $entity->toUrl()->toString(TRUE)->getGeneratedUrl();
    $message = '@plugin_id [@entity_type/@entity_id]: ' . $message . '<br>@entity_name';
    \Drupal::logger('drd')->{$severity}($message, $arguments);
  }

}

==> drd-8.x-3.7.tar.gz: drd/src/Plugin/Action/BaseEntity.php <==
<?php

namespace Drupal\drd\Plugin\Action;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Session\AccountInterface;

/**
 * Base class for DRD Action plugins.
 */
abstract class BaseEntity extends Base implements BaseEntityInterface {

  /** @var \Drupal\drd\Entity\BaseInterface */
  protected $drdEntity;

  /**
   * {@inheritdoc}
   */
  public function access($domain, AccountInterface $account = NULL, $return_as_object = FALSE) {
    if (!isset($domain)) {
      // This is a general check if we have access to the action itself.
      return parent::access($domain, $account, $return_as_object);
    }

    $this->drdEntity = $domain;
    if (parent::access($domain, $account)) {
      return $this->drdEntity->access('edit', $account, $return_as_object);
    }
    return $return_as_object ? AccessResult::forbidden() : FALSE;
  }

  /**
   * @param \Drupal\Core\Entity\EntityInterface $entity
   * @param string $severity
   * @param string $message
   * @param array $arguments
   */
  protected function log($entity, $severity, $message, $arguments = []) {
    if (!method_exists(\Drupal::logger('drd'), $severity)) {
      $severity = 'emergency';
    }
    $arguments['@plugin_id'] = $this->pluginId;
    $arguments['@entity_id'] = $entity->id();
    $arguments['@entity_name'] = $entity->label();
    $arguments['@entity_type'] = $entity->getEntityTypeId();
    $arguments['link'] = $entity->toUrl()->toString(TRUE)->getGeneratedUrl();
    $message = '@plugin_id [@entity_type/@entity_id]: ' . $message . '<br>@entity_name';
    if (!isset($this->io)) {
      \Drupal::logger('drd')->{$severity}($message, $arguments);
    }
    else {
      $this->io->note($this->t($message, $arguments)->render());
    }
  }

}
